@@ -42,7 +42,7 @@ class AbstractGeneratorXml(object):
 
     @property
     def cadena_original(self) -> str:
-        return str(self.cadena_original_value).replace('\n', '').replace(' ', '').strip()
+        return self.cadena_original_value
 
     @abstractmethod
     def generate_xml(self):
